==> qtcreator_4.8.2.orig.tar.xz: qt-creator-opensource-src-4.8.2/src/libs/clangsupport/refactoringserverproxy.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "baseserverproxy.h"
#include "clangsupport_global.h"
#include "refactoringserverinterface.h"
#include "readmessageblock.h"
#include "writemessageblock.h"

#include <QtGlobal>

#include <memory>

QT_BEGIN_NAMESPACE
class QIODevice;
QT_END_NAMESPACE

namespace ClangBackEnd {

class RefactoringClientInterface;

class CLANGSUPPORT_EXPORT RefactoringServerProxy final : public BaseServerProxy,
                                                         public RefactoringServerInterface
{
public:
    explicit RefactoringServerProxy(RefactoringClientInterface *client, QIODevice *ioDevice);

    void end() override;
    void requestSourceLocationsForRenamingMessage(RequestSourceLocationsForRenamingMessage &&message) override;
    void requestSourceRangesAndDiagnosticsForQueryMessage(RequestSourceRangesAndDiagnosticsForQueryMessage &&message) override;
    void requestSourceRangesForQueryMessage(RequestSourceRangesForQueryMessage &&message) override;
    void updateProjectParts(UpdateProjectPartsMessage &&message) override;
    void removeProjectParts(RemoveProjectPartsMessage &&message) override;
    void updateGeneratedFiles(UpdateGeneratedFilesMessage &&message) override;
    void removeGeneratedFiles(RemoveGeneratedFilesMessage &&message) override;
    void cancel() override;
};

} // namespace ClangBackEnd

==> qtcreator_4.14.1.orig.tar.xz: qt-creator-opensource-src-4.14.1/src/libs/clangsupport/refactoringserverproxy.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "baseserverproxy.h"
#include "clangsupport_global.h"
#include "refactoringserverinterface.h"
#include "readmessageblock.h"
#include "writemessageblock.h"

#include <QtGlobal>

#include <memory>

QT_BEGIN_NAMESPACE
class QIODevice;
QT_END_NAMESPACE

namespace ClangBackEnd {

class RefactoringClientInterface;

class CLANGSUPPORT_EXPORT RefactoringServerProxy final : public BaseServerProxy,
                                                         public RefactoringServerInterface
{
public:
    explicit RefactoringServerProxy(RefactoringClientInterface *client,
                                    QLocalSocket *localSocket = {});
    explicit RefactoringServerProxy(RefactoringClientInterface *client, QIODevice *ioDevice);

    void end() override;
    void requestSourceRangesAndDiagnosticsForQueryMessage(RequestSourceRangesAndDiagnosticsForQueryMessage &&message) override;
    void requestSourceRangesForQueryMessage(RequestSourceRangesForQueryMessage &&message) override;
    void updateProjectParts(UpdateProjectPartsMessage &&message) override;
    void removeProjectParts(RemoveProjectPartsMessage &&message) override;
    void updateGeneratedFiles(UpdateGeneratedFilesMessage &&message) override;
    void removeGeneratedFiles(RemoveGeneratedFilesMessage &&message) override;
    void cancel() override;
};

} // namespace ClangBackEnd
